<?php defined('SYSPATH') or die('No direct script access.');

class HTTP_Exception_400 extends Kohana_HTTP_Exception_400 {}